format binary as ""                     ; Binary file format without extension

use32                                   ; Tell compiler to use 32 bit instructions
org 0                                   ; the base address of code, always 0x0

; The header
db 'MENUET01'
dd 1
dd START
dd I_END
dd MEM
dd STACKTOP
dd 0, 0

; The code area

include './BSI/macros.inc'
include 'editbox.inc'
use_edit_box
include 'check.inc'     ;  check.inc
version_ch1             ;    new  check_box1
use_check_box           ;       

START:                                  ; start of execution
   mov  eax,48             ;  
   mov  ebx,3
   mov  ecx,sc
   mov  edx,sizeof.system_colors
   mcall

   mov  eax,40          ;    
   mov  ebx,0x27        ;       , ,  ,    (-  -      ;   )
   mcall

   call    draw_window             ; draw the window
event_wait:
        mov     eax, 10                 ; function 10 : wait until event
        mcall                           ; event type is returned in eax

        cmp     eax, 1                  ; Event redraw request ?
        je      red                     ; Expl.: there has been activity on screen and
                                        ; parts of the applications has to be redrawn.

        cmp     eax, 2                  ; Event key in buffer ?
        je      key                     ; Expl.: User has pressed a key while the
                                        ; app is at the top of the window stack.

        cmp     eax, 3                  ; Event button in buffer ?
        je      button                  ; Expl.: User has pressed one of the
                                        ; applications buttons.

        mouse_edit_boxes editboxes,editboxes_end
        mouse_check_boxes check_boxes,check_boxes_end  ;  
        jmp     event_wait


red:                                    ; Redraw event handler
        call    draw_window             ; We call the window_draw function and
        jmp     event_wait              ; jump back to event_wait

key:                                    ; Keypress event handler
        mov     eax, 2                  ; The key is returned in ah. The key must be
        mcall                           ; read and cleared from the system queue.
        key_edit_boxes editboxes,editboxes_end
        jmp     event_wait              ; Just read the key, ignore it and jump to event_wait.

button:                                 ; Buttonpress event handler
        mov     eax,17                  ; The button number defined in window_draw
        mcall                           ; is returned to ah.

        cmp     ah,1                    ; button id=1 ?
        jne     noclose
        mov     eax,-1                  ; Function -1 : close this program
        mcall

noclose:

   cmp ah, 2
   jne no_format
   call format_action
   jmp     event_wait

no_format:
    cmp ah, 2
   jne no_browser
   call brouse_action
   jmp     event_wait
no_browser:
        jmp     event_wait              ; This is for ignored events, useful at development

brouse_action:
   ret
format_action:
   ret

draw_window:
        mov     eax, 12                 ; function 12: tell os about windowdraw
        mov     ebx, 1                  ; 1, start of draw
        mcall

        mov     eax, 0                  ; function 0 : define and draw window
        mov     ebx, 100 * 65536 + 290  ; [x start] *65536 + [x size]
        mov     ecx, 100 * 65536 + 310  ; [y start] *65536 + [y size]
        mov     edx, 0x14ffffff         ; color of work area RRGGBB
                                        ; 0x02000000 = window type 4 (fixed size, skinned window)
        mov     esi, 0x808899ff         ; color of grab bar  RRGGBB
                                        ; 0x80000000 = color glide
        mov     edi, title
        mcall

        mov eax, 8
        mov ebx, (290-160)*65536+130
        mov ecx, 270*65536+20
        mov edx, 2
        mov esi, 0xAABBCC ;4466AA
        mcall

        mov eax, 8
        mov ebx, 210*65536+50
        mov ecx, 210*65536+14
        mov edx, 3
        mov esi, 0xAABBCC ;D7D7D7 ;4466AA
        mcall

        draw_check_boxes check_boxes,check_boxes_end ; 
        draw_edit_boxes editboxes,editboxes_end      ; edit box'

        call draw_super_text

        mov     eax, 12                 ; function 12:tell os about windowdraw
        mov     ebx, 2                  ; 2, end of draw
        mcall

        ret


title   db  "Formatting Disk Utility", 0
Otstup = 30

 align 4
 check_boxes:
;>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
;DATA    check_box1 -   
;   :
;10 -     
;30 -     
;ch_text.1 -    
;ch_text.e1-ch_text.1 -  

;
ch1 check_box1 Otstup,170,ch_text.1,ch_text.e1-ch_text.1;,ch_flag_en
ch2 check_box1 Otstup,190,ch_text.2,ch_text.e2-ch_text.2;,ch_flag_en
check_boxes_end:

ch_text:        ;    
.1 db 'Full and long disk formatting'
.e1:
.2 db 'Create startup disk, write MBR:'
.e2:



text:
  .volume db 'Volume Label:', 0
  .fs     db 'File System:', 0
  .disk   db 'Capacity:', 0
  .unit   db 'Allocation unit size:', 0
  .option db 'Options:', 0
  .format db 'Format', 0
  .browse db 'Browse', 0

draw_super_text:
   push eax ebx ecx edx edi esi
   mov     ebx, Otstup * 65536 + 49    ; draw info text with function 4 (x, y)
   mov     ecx, 0x224466
   mov eax, text.volume
   mov     edx, eax
   mov     esi, 13
   mcall 4

   mov     ebx, Otstup * 65536 + 99
   mov     edx, text.fs
   mov     esi, 12
   mcall 4

   mov     ebx, (Otstup+80+30) * 65536 + 99
   mov     edx, text.unit
   mov     esi, 21
   mcall 4

   mov     ebx, (Otstup+80+30) * 65536 + 49
   mov     edx, text.disk
   mov     esi, 9
   mcall 4

   mov     ebx, Otstup * 65536 + 151
   mov     edx, text.option
   mov     esi, 8
   mcall 4

   ;buttons text
   mov     ebx, 180 * 65536 + 277
   mov     ecx, 0xFFFFFF
   mov eax, text.format
   mov     edx, eax
   mov     esi, 6
   mcall 4

   mov     ebx, 217 * 65536 + 213
   mov     ecx, 0xFFFFFF
   mov eax, text.browse
   mov     edx, eax
   mov     esi, 6
   mcall 4

   pop esi edi edx ecx ebx eax
   ret


;>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
;DATA 
editboxes:;ed_figure_only
editLU edit_box 80,Otstup,60,0xffffff,0x6a9480,0,0xAABBCC,0,8,Buf.1,ed_focus,8,8
editLD edit_box 80,Otstup,110,0xffffff,0x6a9480,0,0xAABBCC,0,3,Buf.2,ed_focus,3,3
editRU edit_box 120,Otstup+80+30,60,0xffffff,0x6a9480,0,0xAABBCC,0,16,Buf.3,ed_focus,16,16
editRD edit_box 120,Otstup+80+30,110,0xffffff,0x6a9480,0,0xAABBCC,0,4,Buf.4,ed_focus,4,4
editMBR edit_box 160,Otstup+20,210,0xffffff,0x6a9480,0,0xAABBCC,0,25,Buf.5,ed_focus,25,25
editboxes_end:
data_of_code dd 0
mouse_flag dd 0x0


sc     system_colors

Buf:
  .1 db 'NONAME18',0,0
  .2 db 'FAT',0,0 ;100 dup(0)
  .3 db 'hd0 [FAT32: 4Gb]',0,0 ;100 dup(0)
  .4 db '4096',0,0 ;100 dup(0)
  .5 db '/rd/1/format/fat32mbr.bin', 0, 0
I_END:
        rb 4096
STACKTOP:

MEM:

; The area after I_END is free for use as the application memory,
; just avoid the stack.
;
; Application memory structure, according to the used header, 1 Mb.
;
; 0x00000   - Start of compiled image
; I_END     - End of compiled image
;
;           + Free for use in the application
;
; STACKTOP  - Start of stack area               - defined in the header
; STACKTOP-4096 - End of stack area
;
;           + Free for use in the application
;
; MEM       - End of freely useable memory      - defined in the header
;
; All of the the areas can be modified within the application with a
; direct reference.
; For example, mov [STACKTOP-1],byte 1 moves a byte above the stack area.